@@ -4,11 +4,14 @@ use Mojo::Base -strict;
 use FindBin;
 use lib "$FindBin::Bin/../../lib";
 use Net::OAuth::LP::Client;
-use DDP;
+use v5.14;
 
 my $client = Net::OAuth::LP::Client->new;
+
 $client->consumer_key('cts-pika-bot');
 $client->login_with_creds;
 
-p $client;
+say "Consumer key: " . $client->consumer_key;
+say "Token: " . $client->access_token;
+say "Token secret: ". $client->access_token_secret;
 
